@@ -103,7 +103,7 @@ int dir_export_init(const char *fn);
 
 
 /* Function set by input code. Returns dir_output.final(). */
-extern int (*dir_process)();
+extern int (*dir_process)(void);
 
 /* Scanning a live directory */
 extern int dir_scan_smfs;
@@ -113,6 +113,10 @@ void dir_scan_init(const char *path);
 extern int dir_import_active;
 int dir_import_init(const char *fn);
 
+#if HAVE_LINUX_MAGIC_H && HAVE_SYS_STATFS_H && HAVE_STATFS
+extern int exclude_kernfs;
+#endif
+
 
 /* The currently configured output functions. */
 extern struct dir_output dir_output;
@@ -121,7 +125,7 @@ extern struct dir_output dir_output;
 extern char *dir_curpath;
 void dir_curpath_set(const char *);
 void dir_curpath_enter(const char *);
-void dir_curpath_leave();
+void dir_curpath_leave(void);
 
 /* Sets the path where the last error occurred, or reset on NULL. */
 void dir_setlasterr(const char *);
@@ -132,6 +136,6 @@ void dir_seterr(const char *, ...);
 
 extern int dir_ui;
 int dir_key(int);
-void dir_draw();
+void dir_draw(void);
 
 #endif
