@@ -42,6 +42,7 @@ long update_delay = 100;
 int cachedir_tags = 0;
 int extended_info = 0;
 int follow_symlinks = 0;
+int follow_firmlinks = 0;
 int confirm_quit = 0;
 
 static int min_rows = 17, min_cols = 60;
@@ -50,7 +51,7 @@ static int ncurses_tty = 0; /* Explicitely open /dev/tty instead of using stdio
 static long lastupdate = 999;
 
 
-static void screen_draw() {
+static void screen_draw(void) {
   switch(pstate) {
     case ST_CALC:   dir_draw();    break;
     case ST_BROWSE: browse_draw(); break;
@@ -74,7 +75,7 @@ int input_handle(int wait) {
   if(wait != 1)
     screen_draw();
   else {
-    gettimeofday(&tv, (void *)NULL);
+    gettimeofday(&tv, NULL);
     tv.tv_usec = (1000*(tv.tv_sec % 1000) + (tv.tv_usec / 1000)) / update_delay;
     if(lastupdate != tv.tv_usec) {
       screen_draw();
@@ -106,7 +107,7 @@ int input_handle(int wait) {
     }
     screen_draw();
   }
-  if(errno == EPIPE || errno == EBADF)
+  if(errno == EPIPE || errno == EBADF || errno == EIO)
       return 1;
   return 0;
 }
@@ -137,6 +138,8 @@ static void argv_parse(int argc, char **argv) {
     { 'X', 1, "-X,--exclude-from" },
     { 'L', 0, "-L,--follow-symlinks" },
     { 'C', 0, "--exclude-caches" },
+    {  2,  0, "--exclude-kernfs" },
+    {  3,  0, "--follow-firmlinks" },
     { 's', 0, "--si" },
     { 'Q', 0, "--confirm-quit" },
     { 'c', 1, "--color" },
@@ -166,8 +169,14 @@ static void argv_parse(int argc, char **argv) {
       printf("  -X, --exclude-from FILE    Exclude files that match any pattern in FILE\n");
       printf("  -L, --follow-symlinks      Follow symbolic links (excluding directories)\n");
       printf("  --exclude-caches           Exclude directories containing CACHEDIR.TAG\n");
+#if HAVE_LINUX_MAGIC_H && HAVE_SYS_STATFS_H && HAVE_STATFS
+      printf("  --exclude-kernfs           Exclude Linux pseudo filesystems (procfs,sysfs,cgroup,...)\n");
+#endif
+#if HAVE_SYS_ATTR_H && HAVE_GETATTRLIST && HAVE_DECL_ATTR_CMNEXT_NOFIRMLINKPATH
+      printf("  --follow-firmlinks         Follow firmlinks on macOS\n");
+#endif
       printf("  --confirm-quit             Confirm quitting ncdu\n");
-      printf("  --color SCHEME             Set color scheme\n");
+      printf("  --color SCHEME             Set color scheme (off/dark)\n");
       exit(0);
     case 'q': update_delay = 2000; break;
     case 'v':
@@ -194,6 +203,21 @@ static void argv_parse(int argc, char **argv) {
     case 'C':
       cachedir_tags = 1;
       break;
+
+    case  2 :
+#if HAVE_LINUX_MAGIC_H && HAVE_SYS_STATFS_H && HAVE_STATFS
+      exclude_kernfs = 1; break;
+#else
+      fprintf(stderr, "This feature is not supported on your platform\n");
+      exit(1);
+#endif
+    case  3 :
+#if HAVE_SYS_ATTR_H && HAVE_GETATTRLIST && HAVE_DECL_ATTR_CMNEXT_NOFIRMLINKPATH
+      follow_firmlinks = 1; break;
+#else
+      fprintf(stderr, "This feature is not supported on your platform\n");
+      exit(1);
+#endif
     case 'c':
       if(strcmp(val, "off") == 0)  { uic_theme = 0; }
       else if(strcmp(val, "dark") == 0) { uic_theme = 1; }
@@ -236,7 +260,7 @@ static void argv_parse(int argc, char **argv) {
 
 
 /* Initializes ncurses only when not done yet. */
-static void init_nc() {
+static void init_nc(void) {
   int ok = 0;
   FILE *tty;
   SCREEN *term;
